@@ -152,6 +152,7 @@ static void atexit_fun()
 static void sig_winch(int s)
 {
     if(gMainLoop == -1) {
+        resizeterm(mgetmaxy(), mgetmaxx());
         xclear_immediately();       // refresh
         view();
         refresh();
@@ -239,302 +240,303 @@ static void set_mfenv()
     char buf[128];
 
     snprintf(buf, 128, "%d", KEY_UP);
-    setenv("key_up", buf, 1);
+    uobject_put(gMFiler4, "key_up", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_RIGHT);
-    setenv("key_right", buf, 1);
+    uobject_put(gMFiler4, "key_right", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_DOWN);
-    setenv("key_down", buf, 1);
+    uobject_put(gMFiler4, "key_down", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_LEFT);
-    setenv("key_left", buf, 1);
+    uobject_put(gMFiler4, "key_left", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_IC);
-    setenv("key_insert", buf, 1);
+    uobject_put(gMFiler4, "key_insert", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_DC);
-    setenv("key_delete2", buf, 1);
+    uobject_put(gMFiler4, "key_delete2", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", 127);
-    setenv("key_delete", buf, 1);
+    uobject_put(gMFiler4, "key_delete", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_HOME);
-    setenv("key_home", buf, 1);
+    uobject_put(gMFiler4, "key_home", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_END);
-    setenv("key_end", buf, 1);
+    uobject_put(gMFiler4, "key_end", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_PPAGE);
-    setenv("key_pageup", buf, 1);
+    uobject_put(gMFiler4, "key_pageup", STRING_NEW_GC(buf, TRUE));
     snprintf(buf, 128, "%d", KEY_NPAGE);
-    setenv("key_pagedown", buf, 1);
+    uobject_put(gMFiler4, "key_pagedown", STRING_NEW_GC(buf, TRUE));
 
     snprintf(buf,128, "%d", 10);
-    setenv("key_enter", buf, 1);
+    uobject_put(gMFiler4, "key_enter", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_BACKSPACE);
-    setenv("key_backspace", buf, 1);
+    uobject_put(gMFiler4, "key_backspace", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(1));
-    setenv("key_f1", buf, 1);
+    uobject_put(gMFiler4, "key_f1", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(2));
-    setenv("key_f2", buf, 1);
+    uobject_put(gMFiler4, "key_f2", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(3));
-    setenv("key_f3", buf, 1);
+    uobject_put(gMFiler4, "key_f3", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(4));
-    setenv("key_f4", buf, 1);
+    uobject_put(gMFiler4, "key_f4", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(5));
-    setenv("key_f5", buf, 1);
+    uobject_put(gMFiler4, "key_f5", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(6));
-    setenv("key_f6", buf, 1);
+    uobject_put(gMFiler4, "key_f6", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(7));
-    setenv("key_f7", buf, 1);
+    uobject_put(gMFiler4, "key_f7", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(8));
-    setenv("key_f8", buf, 1);
+    uobject_put(gMFiler4, "key_f8", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(9));
-    setenv("key_f9", buf, 1);
+    uobject_put(gMFiler4, "key_f9", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(10));
-    setenv("key_f10", buf, 1);
+    uobject_put(gMFiler4, "key_f10", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(11));
-    setenv("key_f11", buf, 1);
+    uobject_put(gMFiler4, "key_f11", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", KEY_F(12));
-    setenv("key_f12", buf, 1);
+    uobject_put(gMFiler4, "key_f12", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'a');
-    setenv("key_a", buf, 1);
+    uobject_put(gMFiler4, "key_a", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'b');
-    setenv("key_b", buf, 1);
+    uobject_put(gMFiler4, "key_b", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'c');
-    setenv("key_c", buf, 1);
+    uobject_put(gMFiler4, "key_c", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'd');
-    setenv("key_d", buf, 1);
+    uobject_put(gMFiler4, "key_d", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'e');
-    setenv("key_e", buf, 1);
+    uobject_put(gMFiler4, "key_e", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'f');
-    setenv("key_f", buf, 1);
+    uobject_put(gMFiler4, "key_f", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'g');
-    setenv("key_g", buf, 1);
+    uobject_put(gMFiler4, "key_g", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'h');
-    setenv("key_h", buf, 1);
+    uobject_put(gMFiler4, "key_h", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'i');
-    setenv("key_i", buf, 1);
+    uobject_put(gMFiler4, "key_i", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'j');
-    setenv("key_j", buf, 1);
+    uobject_put(gMFiler4, "key_j", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'k');
-    setenv("key_k", buf, 1);
+    uobject_put(gMFiler4, "key_k", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'l');
-    setenv("key_l", buf, 1);
+    uobject_put(gMFiler4, "key_l", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'm');
-    setenv("key_m", buf, 1);
+    uobject_put(gMFiler4, "key_m", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'n');
-    setenv("key_n", buf, 1);
+    uobject_put(gMFiler4, "key_n", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'o');
-    setenv("key_o", buf, 1);
+    uobject_put(gMFiler4, "key_o", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'p');
-    setenv("key_p", buf, 1);
+    uobject_put(gMFiler4, "key_p", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'q');
-    setenv("key_q", buf, 1);
+    uobject_put(gMFiler4, "key_q", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'r');
-    setenv("key_r", buf, 1);
+    uobject_put(gMFiler4, "key_r", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 's');
-    setenv("key_s", buf, 1);
+    uobject_put(gMFiler4, "key_s", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 't');
-    setenv("key_t", buf, 1);
+    uobject_put(gMFiler4, "key_t", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'u');
-    setenv("key_u", buf, 1);
+    uobject_put(gMFiler4, "key_u", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'v');
-    setenv("key_v", buf, 1);
+    uobject_put(gMFiler4, "key_v", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'w');
-    setenv("key_w", buf, 1);
+    uobject_put(gMFiler4, "key_w", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'x');
-    setenv("key_x", buf, 1);
+    uobject_put(gMFiler4, "key_x", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'y');
-    setenv("key_y", buf, 1);
+    uobject_put(gMFiler4, "key_y", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'z');
-    setenv("key_z", buf, 1);
+    uobject_put(gMFiler4, "key_z", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'A');
-    setenv("key_A", buf, 1);
+    uobject_put(gMFiler4, "key_A", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'B');
-    setenv("key_B", buf, 1);
+    uobject_put(gMFiler4, "key_B", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'C');
-    setenv("key_C", buf, 1);
+    uobject_put(gMFiler4, "key_C", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'D');
-    setenv("key_D", buf, 1);
+    uobject_put(gMFiler4, "key_D", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'E');
-    setenv("key_E", buf, 1);
+    uobject_put(gMFiler4, "key_E", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'F');
-    setenv("key_F", buf, 1);
+    uobject_put(gMFiler4, "key_F", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'G');
-    setenv("key_G", buf, 1);
+    uobject_put(gMFiler4, "key_G", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'H');
-    setenv("key_H", buf, 1);
+    uobject_put(gMFiler4, "key_H", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'I');
-    setenv("key_I", buf, 1);
+    uobject_put(gMFiler4, "key_I", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'J');
-    setenv("key_J", buf, 1);
+    uobject_put(gMFiler4, "key_J", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'K');
-    setenv("key_K", buf, 1);
+    uobject_put(gMFiler4, "key_K", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'L');
-    setenv("key_L", buf, 1);
+    uobject_put(gMFiler4, "key_L", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'M');
-    setenv("key_M", buf, 1);
+    uobject_put(gMFiler4, "key_M", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'N');
-    setenv("key_N", buf, 1);
+    uobject_put(gMFiler4, "key_N", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'O');
-    setenv("key_O", buf, 1);
+    uobject_put(gMFiler4, "key_O", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'P');
-    setenv("key_P", buf, 1);
+    uobject_put(gMFiler4, "key_P", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'Q');
-    setenv("key_Q", buf, 1);
+    uobject_put(gMFiler4, "key_Q", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'R');
-    setenv("key_R", buf, 1);
+    uobject_put(gMFiler4, "key_R", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'S');
-    setenv("key_S", buf, 1);
+    uobject_put(gMFiler4, "key_S", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'T');
-    setenv("key_T", buf, 1);
+    uobject_put(gMFiler4, "key_T", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'U');
-    setenv("key_U", buf, 1);
+    uobject_put(gMFiler4, "key_U", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'V');
-    setenv("key_V", buf, 1);
+    uobject_put(gMFiler4, "key_V", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'W');
-    setenv("key_W", buf, 1);
+    uobject_put(gMFiler4, "key_W", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'X');
-    setenv("key_X", buf, 1);
+    uobject_put(gMFiler4, "key_X", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'Y');
-    setenv("key_Y", buf, 1);
+    uobject_put(gMFiler4, "key_Y", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 'Z');
-    setenv("key_Z", buf, 1);
+    uobject_put(gMFiler4, "key_Z", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 32);
-    setenv("key_space", buf, 1);
+    uobject_put(gMFiler4, "key_space", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 1);
-    setenv("key_ctrl_a", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_a", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 2);
-    setenv("key_ctrl_b", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_b", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 3);
-    setenv("key_ctrl_c", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_c", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 4);
-    setenv("key_ctrl_d", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_d", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 5);
-    setenv("key_ctrl_e", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_e", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 6);
-    setenv("key_ctrl_f", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_f", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 7);
-    setenv("key_ctrl_g", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_g", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 8);
-    setenv("key_ctrl_h", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_h", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 9);
-    setenv("key_ctrl_i", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_i", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 10);
-    setenv("key_ctrl_j", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_j", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 11);
-    setenv("key_ctrl_k", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_k", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 12);
-    setenv("key_ctrl_l", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_l", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 13);
-    setenv("key_ctrl_m", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_m", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 14);
-    setenv("key_ctrl_n", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_n", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 15);
-    setenv("key_ctrl_o", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_o", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 16);
-    setenv("key_ctrl_p", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_p", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 17);
-    setenv("key_ctrl_q", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_q", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 18);
-    setenv("key_ctrl_r", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_r", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 19);
-    setenv("key_ctrl_s", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_s", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 20);
-    setenv("key_ctrl_t", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_t", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 21);
-    setenv("key_ctrl_u", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_u", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 22);
-    setenv("key_ctrl_v", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_v", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 23);
-    setenv("key_ctrl_w", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_w", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 24);
-    setenv("key_ctrl_x", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_x", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 25);
-    setenv("key_ctrl_y", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_y", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 26);
-    setenv("key_ctrl_z", buf, 1);
+    uobject_put(gMFiler4, "key_ctrl_z", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 27);
-    setenv("key_escape", buf, 1);
+    uobject_put(gMFiler4, "key_escape", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", 9);
-    setenv("key_tab", buf, 1);
+    uobject_put(gMFiler4, "key_tab", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '0');
-    setenv("key_0", buf, 1);
+    uobject_put(gMFiler4, "key_0", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '1');
-    setenv("key_1", buf, 1);
+    uobject_put(gMFiler4, "key_1", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '2');
-    setenv("key_2", buf, 1);
+    uobject_put(gMFiler4, "key_2", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '3');
-    setenv("key_3", buf, 1);
+    uobject_put(gMFiler4, "key_3", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '4');
-    setenv("key_4", buf, 1);
+    uobject_put(gMFiler4, "key_4", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '5');
-    setenv("key_5", buf, 1);
+    uobject_put(gMFiler4, "key_5", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '6');
-    setenv("key_6", buf, 1);
+    uobject_put(gMFiler4, "key_6", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '7');
-    setenv("key_7", buf, 1);
+    uobject_put(gMFiler4, "key_7", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '8');
-    setenv("key_8", buf, 1);
+    uobject_put(gMFiler4, "key_8", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '9');
-    setenv("key_9", buf, 1);
+    uobject_put(gMFiler4, "key_9", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '!');
-    setenv("key_exclam", buf, 1);
+    uobject_put(gMFiler4, "key_exclam", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '"');
-    setenv("key_dquote", buf, 1);
+    uobject_put(gMFiler4, "key_dquote", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '#');
-    setenv("key_sharp", buf, 1);
+    uobject_put(gMFiler4, "key_sharp", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '$');
-    setenv("key_dollar", buf, 1);
+    uobject_put(gMFiler4, "key_dollar", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '%');
-    setenv("key_percent", buf, 1);
+    uobject_put(gMFiler4, "key_percent", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '&');
-    setenv("key_and", buf, 1);
+    uobject_put(gMFiler4, "key_and", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '\'');
-    setenv("key_squote", buf, 1);
+    uobject_put(gMFiler4, "key_squote", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '(');
-    setenv("key_lparen", buf, 1);
+    uobject_put(gMFiler4, "key_lparen", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", ')');
-    setenv("key_rparen", buf, 1);
+    uobject_put(gMFiler4, "key_rparen", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '~');
-    setenv("key_tilda", buf, 1);
+    uobject_put(gMFiler4, "key_tilda", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '=');
-    setenv("key_equal", buf, 1);
+    uobject_put(gMFiler4, "key_equal", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '-');
-    setenv("key_minus", buf, 1);
+    uobject_put(gMFiler4, "key_minus", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '^');
-    setenv("key_cup", buf, 1);
+    uobject_put(gMFiler4, "key_cup", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '|');
-    setenv("key_vbar", buf, 1);
+    uobject_put(gMFiler4, "key_vbar", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '\\');
-    setenv("key_backslash", buf, 1);
+    uobject_put(gMFiler4, "key_backslash", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '@');
-    setenv("key_atmark", buf, 1);
+    uobject_put(gMFiler4, "key_atmark", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '`');
-    setenv("key_bapostrophe", buf, 1);
+    uobject_put(gMFiler4, "key_bapostrophe", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '{');
-    setenv("key_lcurly", buf, 1);
+    uobject_put(gMFiler4, "key_lcurly", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '[');
-    setenv("key_lbrack", buf, 1);
+    uobject_put(gMFiler4, "key_lbrack", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '+');
-    setenv("key_plus", buf, 1);
+    uobject_put(gMFiler4, "key_plus", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", ';');
-    setenv("key_semicolon", buf, 1);
+    uobject_put(gMFiler4, "key_semicolon", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '*');
-    setenv("key_star", buf, 1);
+    uobject_put(gMFiler4, "key_star", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", ':');
-    setenv("key_colon", buf, 1);
+    uobject_put(gMFiler4, "key_colon", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '}');
-    setenv("key_rcurly", buf, 1);
+    uobject_put(gMFiler4, "key_rcurly", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", ']');
-    setenv("key_rbrack", buf, 1);
+    uobject_put(gMFiler4, "key_rbrack", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '<');
-    setenv("key_lss", buf, 1);
+    uobject_put(gMFiler4, "key_lss", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", ',');
-    setenv("key_comma", buf, 1);
+    uobject_put(gMFiler4, "key_comma", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '>');
-    setenv("key_gtr", buf, 1);
+    uobject_put(gMFiler4, "key_gtr", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '.');
-    setenv("key_dot", buf, 1);
+    uobject_put(gMFiler4, "key_dot", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '/');
-    setenv("key_slash", buf, 1);
+    uobject_put(gMFiler4, "key_slash", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '?');
-    setenv("key_qmark", buf, 1);
+    uobject_put(gMFiler4, "key_qmark", STRING_NEW_GC(buf, TRUE));
     snprintf(buf,128, "%d", '_');
-    setenv("key_underbar", buf, 1);
+    uobject_put(gMFiler4, "key_underbar", STRING_NEW_GC(buf, TRUE));
+
     snprintf(buf,128, "%d", 0);
     setenv("nometa", buf, 1);
     snprintf(buf,128, "%d", 1);
@@ -559,6 +561,33 @@ static void set_mfenv()
     setenv("ma_magenta", buf, 1);
     snprintf(buf,128, "%d", COLOR_PAIR(7));
     setenv("ma_red", buf, 1);
+
+/*
+    snprintf(buf,128, "%d", 0);
+    uobject_put(gMFiler4, "nometa", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", 1);
+    uobject_put(gMFiler4, "meta", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", A_REVERSE);
+    uobject_put(gMFiler4, "ma_reverse", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", A_BOLD);
+    uobject_put(gMFiler4, "ma_bold", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", A_UNDERLINE);
+    uobject_put(gMFiler4, "ma_underline", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", COLOR_PAIR(1));
+    uobject_put(gMFiler4, "ma_white", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", COLOR_PAIR(2));
+    uobject_put(gMFiler4, "ma_blue", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", COLOR_PAIR(3));
+    uobject_put(gMFiler4, "ma_cyan", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", COLOR_PAIR(4));
+    uobject_put(gMFiler4, "ma_green", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", COLOR_PAIR(5));
+    uobject_put(gMFiler4, "ma_yellow", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", COLOR_PAIR(6));
+    uobject_put(gMFiler4, "ma_magenta", STRING_NEW_GC(buf, TRUE));
+    snprintf(buf,128, "%d", COLOR_PAIR(7));
+    uobject_put(gMFiler4, "ma_red", STRING_NEW_GC(buf, TRUE));
+*/
 }
 
 void mygetcwd(char* result, int result_size)
@@ -601,7 +630,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN(FALSE);    // start to watch memory leak
 
     /// initialization for envronment variable ///
-    setenv("VERSION", "1.1.0", 1);
+    setenv("VERSION", "1.1.1", 1);
     setenv("MFILER4_DATAROOTDIR", DATAROOTDIR, 1);
 
     /// save mfiler4 home directory ///
@@ -683,9 +712,6 @@ int main(int argc, char* argv[])
         return 1;
     }
 
-    /// set environment variables ///
-    set_mfenv();
-
     /// initialization for all modules ///
     xyzsh_init(kATConsoleApp, FALSE);
     commands_init();
@@ -694,8 +720,8 @@ int main(int argc, char* argv[])
     gui_init();
     isearch_init();
 
-    /// signal ///
-    set_signal_mfiler();
+    /// set environment variables ///
+    set_mfenv();
 
     /// locale ///
     //if(gTerminalKanjiCode == kTKUtf8) setlocale(LC_CTYPE, "ja_JP.UTF-8");
@@ -777,6 +803,9 @@ int main(int argc, char* argv[])
         mreset_tty();
         exit(1);
     }
+
+    /// signal ///
+    set_signal_mfiler();
     
     /// start curses ///
     xinitscr();
